@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # coding=utf-8
 """
 © 2014 LinkedIn Corp. All rights reserved.
@@ -16,11 +15,14 @@ Correlation object
 
 
 class CorrelationResult(object):
-  def __init__(self, shift, coefficient):
+
+  def __init__(self, shift, coefficient, shifted_coefficient):
     """
     Construct a CorrelationResult object.
     :param int shift: the amount of shift where the coefficient is obtained.
     :param float coefficient: the correlation coefficient.
+    :param float shifted_coefficient: the correlation coefficient with shift taken into account.
     """
     self.shift = shift
-    self.coefficient = coefficient
\ No newline at end of file
+    self.coefficient = coefficient
+    self.shifted_coefficient = shifted_coefficient
\ No newline at end of file
